@@ -4,8 +4,8 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDraw.h"
-       type(Component)::  comp  ! input. component
-       type(epPos)::  p(*)     ! output. (x,y,z) to describe
+      record /Component/ comp  ! input. component
+      record /epPos/ p(*)     ! output. (x,y,z) to describe
                                !   a ocyl in local coordnate.
                                ! (x,y,z)= gpsep is a separator
                                ! to be converted to a blank line
@@ -24,10 +24,10 @@
       logical kdgtest
       real*8 x
 
-       r = Volat( comp%vol + ir)
-       h = Volat( comp%vol + ih)
-       sa= Volat( comp%vol + isa)
-       ea= Volat( comp%vol + iea)
+       r = Volat( comp.vol + ir)
+       h = Volat( comp.vol + ih)
+       sa= Volat( comp.vol + isa)
+       ea= Volat( comp.vol + iea)
 
        n = 0
        if(ea < sa) then
@@ -42,7 +42,7 @@
        nsv2 = n + 1
        n =n + n2
        n = n + 1
-       p(n)%x = gpsep
+       p(n).x = gpsep
        if(kdgtest(howcyl, 1)) then
           call epdrawCylEdg(p(nsv1), n1, 0.d0, p(n+1), n2)
           n = n + n2 
@@ -51,68 +51,68 @@
           call epdrawCylEdg( p(nsv2), n1, h, p(n+1), n2)
           n = n + n2
        endif
-!       if(scut) then
-!           draw startng cut  square
+c       if(scut) then
+c           draw startng cut  square
          n = n + 1
-         p(n)%x = 0.
-         p(n)%y = 0.
-         p(n)%z = 0.
+         p(n).x = 0.
+         p(n).y = 0.
+         p(n).z = 0.
 
          n = n + 1
-         p(n)%x = Volat( comp%vol + ircossa)
-         p(n)%y = Volat( comp%vol + irsinsa)
-         p(n)%z = 0.
+         p(n).x = Volat( comp.vol + ircossa)
+         p(n).y = Volat( comp.vol + irsinsa)
+         p(n).z = 0.
 
          n = n + 1
-         p(n)%x = gpsep
-!        -----------
+         p(n).x = gpsep
+c        -----------
 
          n = n + 1
-         p(n)%x = 0.
-         p(n)%y = 0.
-         p(n)%z = h
+         p(n).x = 0.
+         p(n).y = 0.
+         p(n).z = h
 
          n = n + 1
-         p(n)%x = Volat( comp%vol + ircossa)
-         p(n)%y = Volat( comp%vol + irsinsa)
-         p(n)%z = h
+         p(n).x = Volat( comp.vol + ircossa)
+         p(n).y = Volat( comp.vol + irsinsa)
+         p(n).z = h
 
          n = n + 1
-         p(n)%x = gpsep
+         p(n).x = gpsep
          n = n + 1
-         p(n)%x = gpsep
-!        =============
-!      endif
-!      if(ecut) then
-!           draw endign cut  square
+         p(n).x = gpsep
+c        =============
+c      endif
+c      if(ecut) then
+c           draw endign cut  square
          n = n + 1
-         p(n)%x = Volat( comp%vol + ircosea)
-         p(n)%y = Volat( comp%vol + irsinea)
-         p(n)%z = 0.
+         p(n).x = Volat( comp.vol + ircosea)
+         p(n).y = Volat( comp.vol + irsinea)
+         p(n).z = 0.
 
          n = n + 1
-         p(n)%x = 0.
-         p(n)%y = 0.
-         p(n)%z = 0.
+         p(n).x = 0.
+         p(n).y = 0.
+         p(n).z = 0.
 
          n = n + 1
-         p(n)%x = gpsep
-!        -----------
+         p(n).x = gpsep
+c        -----------
 
          n = n + 1
-         p(n)%x = Volat( comp%vol + ircosea)
-         p(n)%y = Volat( comp%vol + irsinea)
-         p(n)%z = h
+         p(n).x = Volat( comp.vol + ircosea)
+         p(n).y = Volat( comp.vol + irsinea)
+         p(n).z = h
 
          n = n + 1
-         p(n)%x = 0.
-         p(n)%y = 0.
-         p(n)%z = h
+         p(n).x = 0.
+         p(n).y = 0.
+         p(n).z = h
 
          n = n + 1
-         p(n)%x = gpsep
+         p(n).x = gpsep
          n = n + 1
-         p(n)%x = gpsep
-!     endif
+         p(n).x = gpsep
+c     endif
 
       end
