@@ -1,4 +1,3 @@
-#ifndef EPCONDC
 !       angle in the config file is in degree; (e.g  sin(90.)  is 1.0)
 #define DEGANGLE
 !       if f90 is available, USEFORMULA will permit to use
@@ -6,6 +5,7 @@
 #undef  USEFORMULA
 !
 
+
 !       change the next #undef INTINFO to
 !       #define INTINFO, then the system will inform the user
 !       the interaction information for each interaction by calling epUI.
@@ -21,8 +21,6 @@
 
 #undef  INTINFO
 #define  INTINFO
-#endif
-#define EPCONDC
 
 
 
