@@ -31,13 +31,14 @@ c
       integer n
 
       character*160 msg
-c
+
 c
 c
       real*8 a, b, fa, fb, t, ft
 
       real*8  td
       integer j
+      save t, ft
 c
       a = x1
       b = x2
@@ -47,7 +48,14 @@ c
       if(fa * fb .gt. 0.) then
          write(msg,*) ' a, b, fa, fb=',a, b, fa, fb, 'in kbchop'
          call cerrorMsg(msg, 1)
+         write(0,*) ' t, ft=',t, ft 
          n=-2
+         if( abs(fa) < abs(fb) ) then
+            x = a
+         else
+            x = b
+         endif
+         return
       else       
          do j = 1, 100
             if(fa*fb .le. 0.) then
