@@ -12,7 +12,9 @@ c#include  "ZepTrack.h"
       character(len=192)::stackdiskpath
 
       record /epTrack/ bTrack ! copy of aTrack
-      
+#if defined (jaxa) || (jaxaflat)           
+      record /epTrack/dummyTrack(2)   ! to get size
+#endif
       bTrack = aTrack
       if( Making1ry == 1 ) then
          ! now 1ry is being stacked
@@ -33,23 +35,29 @@ c#include  "ZepTrack.h"
          if( DdiskNo == 0 ) then
            ! open direct access file in binary 
             DdiskNo = StackDiskFileNo
-            size= sizeof(bTrack)   ! in bytes
+#if defined (jaxa) || (jaxaflat)
+!  this is not used by  ifort;  loc is non standard but
+!  loc seems to be usable by ifort too. 
+            size = loc( dummyTrack(2)) -loc( dummyTrack(1))
+#else
+            size = sizeof(bTrack)      ! in bytes      
+#endif
             if(StackDiskFile == "scratch" ) then
                open(DdiskNo,  status="scratch",
      *           form="unformatted", access="direct",
-#if !defined Solaris
-     *           recordsize=size)   
-#else
+#if defined (Solaris) || (jaxa) || (jaxaflat)
      *           RECL=size)   
+#else
+     *           recordsize=size)   
 #endif
             else
                call cgetfname(StackDiskFile, stackdiskpath)
                open(DdiskNo,  file=stackdiskpath,
      *           form="unformatted", access="direct",
-#if !defined Solaris
-     *           recordsize=size)   
-#else
+#if defined Solaris || (jaxa) || (jaxaflat)
      *           RECL=size)   
+#else
+     *           recordsize=size)   
 #endif
             endif
             write(0,*) 'memory stack area=',MaxStackSize
