@@ -1,4 +1,5 @@
       subroutine epmuInte
+      use modXsecMedia, xmedia=>media, xelement=>element
       implicit none
 #include  "ZepTrackv.h"
 #include  "ZepTrackp.h"
@@ -7,7 +8,12 @@
 
       real*8 Et
       integer ia, iz
-
+      real(8)::xs, mfp
+!///////////
+!      integer ns
+!      record /epTrack/temp
+!      integer,save:: nelec=0
+!////////////
       if( Move.proc .eq. 'pair' ) then
          call epmuPrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
      *                   Et)
@@ -21,6 +27,18 @@ c              to do so, make cTrack a gamma of energy Et
             call cmkptc(kphoton, 0, 0, cTrack.p)
             call epe2p(cTrack)       ! this may not be needed ; for safety
             call eppair
+!/////////////////
+!            nelec = nelec +1
+!            call epqstn(ns)
+!            call epqsTrack(ns, temp)
+!            write(*,'(a, 2i3,i5, 1p,g15.4)') 'mpair',  nelec,
+!     *       temp.p.code, temp.p.charge, temp.p.fm.p(4)
+!            ns = ns -1
+!            call epqsTrack(ns, temp)
+!            nelec = nelec +1
+!            write(*,'(a, 2i3,i5, 1p,g15.4)') 'mpair',  nelec,
+!     *       temp.p.code, temp.p.charge, temp.p.fm.p(4)
+!////////////////
 c           &&&&&9.06
          elseif( Media(MediaNo).mu.MuPr .eq. 2) then
             Move.dE=Et
@@ -62,11 +80,15 @@ c             routine
                call epe2p(cTrack) ! adjust momentum
 c
                call ep2cosPtcl( cTrack.p )
-c                 for small basic cross section case. 
-               call epfixTarget2(ActiveMdl, Media(MediaNo))
-               call ep2cosCond2(Media(MediaNo).colA, 
-     *                          Media(MediaNo).colZ)
+!                fix target A
+!                  better treatment for photons;  v9.16 (next 2)
                call cfixModel( cTrack.p )  ! reset model since E<mu's
+               call cgetPhotoPxs(ActiveMdl2, cTrack.p, 
+     *              xmedia(mediumNo), xs, mfp)
+               call cfixTarget(xmedia(mediumNo))
+               call epcpTargetInfo
+               call ep2cosCond2   
+
                call cphotop     ! Cosmos function
                call eppushPtcl(cTrack) ! use pos. info from this ptcl
 c                 &&&&&9.06
