@@ -45,6 +45,7 @@ c     see Fig/NewVol2.pdf
 c      
       subroutine eprsqtccl(comp)
       implicit none
+#include "ZepManager.h"
 #include "Zep3Vec.h"
 #include "ZepPos.h"
 #include "Zcnfig.h"
@@ -56,7 +57,9 @@ c
 !             next is mandatory
       call eprpst(comp, 4, 8, 1, 6)
       call ep_sqtcclCnst0(comp)
-      call ep_sqtcclPrintCnst
+      if(MsgLevel >= 2 ) then
+         call ep_sqtcclPrintCnst
+      endif
 
       end subroutine eprsqtccl
 
