@@ -893,15 +893,14 @@ c                            dedx is in GeV/(g/cm^2)
                   lowehvyion  = 
      *              (cTrack.p.fm.p(4)-cTrack.p.mass)/cTrack.p.subcode
      *               < 0.7
-                  call epdedxhvy(Media(MediaNo), cTrack.p, dedx,dedxf)
+                  call epdedxhvy(Media(MediaNo), cTrack.p,
+     *               dedx,dedxf)
                else
                   call epdedxNone(Media(MediaNo), cTrack.p, dedx,dedxf)
                   call epdedxTargetBrems(Media(MediaNo), cTrack.p, 
      *               dEdxbyBrems, dEdxbyBremsf)
                endif
 
-
-
                if(cTrack.p.code .eq. kmuon) then
                   call epmudEdx(Media(MediaNo).mu.MuNI, 
      *                 Media(MediaNo).mu.MuBr, 
@@ -1080,6 +1079,9 @@ c
 c             convert to world coord. starting point of the segment
 
       erg= Move.Track.p.fm.p(4)-Move.Track.p.mass
+      if(erg == 0.) then  !avoid 0 energy in tracking display v9.163
+         erg = max((cTrack.p.fm.p(4)-cTrack.p.mass), 0.d0)
+      endif
       if( TraceErg(1) .le. erg .and.  erg .le. TraceErg(2) ) goto 100
       if( TraceErg(3) .le. erg .and.  erg .le. TraceErg(4) ) goto 100
       if( TraceErg(5) .le. erg .and.  erg .le. TraceErg(6) ) goto 100
