@@ -14,7 +14,8 @@ c
       real*8 shp
       integer i, j
 
-
+!           the output media.elem(j).sigma(i) will not
+!       be used anywhere !!!
       do j = 1, media.noOfElem
          shp = xsecmin          ! (say 10mb)
          do i = 1, nxsec
@@ -36,6 +37,7 @@ c  #include "ZepTrackp.h"
 #include "Zevhnp.h"
 c   
       character*16 model    ! input. Active interaction model.
+            ! for x-section calclation
       record /ptcl/ pj      ! input.  a particle (hadronic)
       record /epmedia/ media  ! input
       real*8 xs             ! output. obtained cross-section for the
@@ -48,7 +50,6 @@ c
       real*8  mbTocm2
       parameter (mbTocm2=1.d-27)
 
-
       if( model == "jam" ) then
          call epxsJam(pj, media)
       elseif( model == "phits" ) then
@@ -57,6 +58,10 @@ c
          call epxsDpmjet3(pj, media)
       elseif( model == "qgsjet2" ) then
          call epxsQgsjet2(pj, media)
+      elseif( model == "epos" ) then
+         call epxsEPOS(pj, media)
+      elseif( model == "sibyll" ) then
+         call epxsSibyll(pj, media)
       elseif( model .eq. 'gheisha' ) then
          call epxsGheisha(pj, media)
       else
@@ -65,7 +70,12 @@ c
       if(media.sumns /= smallxs .and. media.sumns /= largexs) then
 c           prop to rhoc so next two are indep. of rhoc
          xs = media.sumns/media.nd ! mb/cm3 /(1/cm3)
-         mfp = 10.*media.rho/(media.sumns*mbTocm2)   ! in kg/m2. Not in g/cm2
+         if( xs <= 0. ) then
+            xs = smallxs
+            mfp = largexs
+         else
+            mfp = 10.*media.rho/(media.sumns*mbTocm2) ! in kg/m2. Not in g/cm2
+         endif
                                           ! to be consistent with other  part.
 c/////////////
 c         if( pj.code == knuc) then
@@ -88,7 +98,8 @@ c////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zmedia.h"
-#include "ZepTrackp.h"
+!#include "ZepTrackp.h"
+#include "Ztrackp.h"
 #include "Zevhnp.h"
       record /ptcl/ pj  ! input ptcl
       record /epmedia/ media    ! input/output
@@ -150,9 +161,9 @@ cc            call rndc(u)
 cc            if(u <  media.elem(i).A - ia) then
 cc               ia = ia +1
 cc            endif
-cc            if(u < media.elem(i).Z- iz ) then
-cc               iz = iz + 1
-cc            endif
+!            if(u < media.elem(i).Z- iz ) then
+!               iz = iz + 1
+!            endif
             call cphitsXs(pj, ia, iz, elaxs,xs, icon)
 cc             no need to add. xs is already total 2010.Nov.16
 ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
@@ -257,6 +268,99 @@ c  #include "ZepTrackp.h"
       media.sumns = sumns
       end
 
+      subroutine epxsEPOS(pj, media)
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+#include "Zmedia.h"
+c  #include "ZepTrackp.h"
+#include "Zevhnp.h"
+      record /ptcl/ pj  ! input ptcl
+      record /epmedia/ media    ! input/output
+
+      integer i, ia, iz
+      real(8):: sumns,  xs, tga, u, tgz
+
+      record /ptcl/ tg
+
+      sumns=0. 
+      do i =1, media.noOfElem
+         tga = media.elem(i).A
+         tgz = media.elem(i).Z
+         ia =tga 
+         iz =tgz 
+         call rndc(u)
+         if(u .lt.  tga - ia ) then
+            ia = min(ia + 1, 209)
+         endif
+
+         if(ia > 1 ) then
+            call cmkptc(kgnuc, ia, iz, tg)
+         else
+            call cmkptc(knuc, ia, iz, tg)
+         endif
+         tg.fm.p(1:3) = 0.
+         tg.fm.p(4) = tg.mass
+         call ceposIniOneEvent(pj, tg, xs)
+         if( xs == smallxs .or. xs == largexs ) then
+            sumns = xs
+            exit
+         else
+            media.nsigma(i) = xs*media.npercm3(i)
+            sumns = sumns + media.nsigma(i)
+         endif
+      enddo
+      media.sumns = sumns
+      end      subroutine epxsEPOS
+
+      subroutine epxsSibyll(pj, media)
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+#include "Zmedia.h"
+c  #include "ZepTrackp.h"
+#include "Zevhnp.h"
+      record /ptcl/ pj  ! input ptcl
+      record /epmedia/ media    ! input/output
+
+      integer i, ia, iz
+      real(8):: sumns,  xs, tga, u, tgz
+
+      record /ptcl/ tg
+
+      sumns=0. 
+      do i =1, media.noOfElem
+         tga = media.elem(i).A
+         tgz = media.elem(i).Z
+         ia =tga 
+         iz =tgz 
+         call rndc(u)
+         if(u .lt.  tga - ia ) then
+            ia = min(ia + 1, 209)
+         endif
+
+         if(ia > 1 ) then
+            call cmkptc(kgnuc, ia, iz, tg)
+         else
+            call cmkptc(knuc, ia, iz, tg)
+         endif
+         tg.fm.p(1:3) = 0.
+         tg.fm.p(4) = tg.mass
+         if( media.name == "Air" ) then
+            tg.subcode = 0   ! sibyll can do for almos Air target only. 
+         endif
+         call csibyllXs(pj, tg, xs)
+         if( xs == smallxs .or. xs == largexs ) then
+            sumns = xs
+            exit
+         else
+            media.nsigma(i) = xs*media.npercm3(i)
+            sumns = sumns + media.nsigma(i)
+         endif
+      enddo
+      media.sumns = sumns
+      end
+
       subroutine epxsGheisha(pj, media)
       implicit none
 #include "Zptcl.h"
@@ -385,6 +489,8 @@ cc      endif
 c          This may be used for small basic cross
 c     section case so that the xA cross section is
 c     propotinal to A. (for gamma A/ mu A)
+!      for gammma, >=v9.16, epgetPhotoPxs is used and
+!      this is no more used. (epfixTarget is used).
 c         
 
       record /epmedia/media   ! input/output  colElem, colA, colZ are output
@@ -445,3 +551,57 @@ c          int value is taken.
       media.sumns = sumns
       end
 
+      subroutine epgetPhotoPxs(model, pj, media, xs, mfp)
+!        epgetxs for photon hadron production
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+#include "Zmedia.h"
+c  #include "ZepTrackp.h"
+#include "Zevhnp.h"
+c   
+      character*16 model    ! input. Active interaction model.
+            ! for x-section calclation .  at present not used
+      record /ptcl/ pj      ! input.  a photon
+      record /epmedia/ media  ! input
+      real(8),intent(out):: xs   !  obtained cross-section for the
+                            !  media. in mb
+                    !    if xs==smallxs, no collision
+                    !       xs==largexs, instant collision
+      real(8),intent(out):: mfp  !  obtained  mean free path in kg/m2
+
+      real*8  mbTocm2
+      parameter (mbTocm2=1.d-27)
+
+      integer i
+      real(8):: sumns
+
+      sumns = 0.
+      do i = 1, media.noOfElem
+         call cgpXsec(media.elem(i).A, pj.fm.p(4), xs)
+         if( xs == smallxs .or. xs == largexs ) then
+            sumns = xs
+            exit
+         else
+            media.nsigma(i) = xs*media.npercm3(i)
+            sumns = sumns + media.nsigma(i)
+         endif
+      enddo
+      media.sumns = sumns
+
+      if(media.sumns /= smallxs .and. media.sumns /= largexs) then
+         xs = media.sumns/media.nd ! mb/cm3 /(1/cm3)                 
+         if( xs <= 0. ) then
+            xs = smallxs
+            mfp = largexs
+         else
+            mfp = 10.*media.rho/(media.sumns*mbTocm2) ! in kg/m2. 
+         endif
+      elseif( media.sumns == smallxs ) then
+         xs = smallxs
+         mfp = largexs
+      else
+         xs = largexs
+         mfp = smallxs
+      endif
+      end
