@@ -256,7 +256,6 @@ c         else      in l.c of ncx.
 
 c        assume  we may search only box or sphere_w
 c        which is uncontained first.
-
       if(ncx .eq. 0)  then
          posw = pos
       else
@@ -312,28 +311,48 @@ c     *     .and.
 c     *        Det.cmp(i).NContainer .eq. 0) then
          !!!!!!!!v9.14 only world is with NContainer= 0
          !!!! so skip non-world comp. 
+c//////////
+c         write(0,*) ' i=',i,  ' Det.cmp(i).NContainer=', 
+c     *        Det.cmp(i).NContainer
+c         write(0,*) ' i=',i,  ' Det.cmp(i).NPContainer=', 
+c     *        Det.cmp(i).NPContainer
+c         write(0,*) ' i=',1,  ' Det.cmp(1).NPContainer=', 
+c     *        Det.cmp(1).NPContainer
+c////////////
          if( i < Det.nct .and. Det.nworld == 1 ) then
             nc= Det.nct+1
+c////////////
+!            write(0,*) ' i=',i,' < Det.nct && nworld=1'
+!            write(0,*) 'so goto 10'
+c//////////////
             goto 10
          endif
          !!!!!!!!
-         if(Det.cmp(i).NContainer .eq. 0) then
+         if(Det.cmp(i).NContainer .eq. 0 .and.   !! added
+     *      Det.cmp(i).NPContainer == 0 ) then
             call epw2l(i, posw, posl)
+c//////////
+!            write(0,*) ' posw=',posw.x,posw.y, posw.z
+c//////////////////
+!            write(0,*) ' converted to posl for i=',i
+!            write(0,*) 'posl=',posl.x,posl.y, posl.z
+!            write(0,*) '  posl is examined by epsOne'
+c/////////////////
             call epsOne(i, posl, icon)
 c///////////////
-c            call debugpos('eppos2cn;epsOne', i, posl,icon)
+!            call debugpos('eppos2cn;epsOne', i, posl,icon)
 c//////////////////
             if(icon .eq.  0) then
                call epsMatreska(i, posl, nc)
 c///////////////
-c             call debugpos('eppos2cn;epsOne;matre', i, posl,icon)
+!             call debugpos('eppos2cn;epsOne;matre', i, posl,icon)
 c//////////////////
                if(nc .ne. i) then
                   call epw2l(nc, posw, posl)
                endif
                call epsPCont(nc, posl, jcon)
 c///////////////
-c            call debugpos('eppos2cn;epsOne;PCont', nc, posl,jcon)
+!            call debugpos('eppos2cn;epsOne;PCont', nc, posl,jcon)
 c//////////////////
                if(jcon .ne. 0) then
                   nc = Det.nct + 1
@@ -379,6 +398,9 @@ c//////////////////
       nc= Det.nct+1
 
  10   continue
+c///////////
+!      write(0,*) ' exiting epsall: nc=',nc
+c////////////
       end
 c     ***************************************
       subroutine epsbox(ncx, aTrack, nc)
